PATH_USERS = "users"
PATH_USERS_DELETE = "users/{userId}"

PATH_AUTH_LOGIN = "auth/login"

PATH_LOGS_SINGLES = "logs/singles"

PATH_GET_COMPARE = "logs/compare"
PATH_POST_COMPARE = "logs/compare"
PATH_GET_COMPARE_ID = "logs/compare/{compareId}"
PATH_DELETE_COMPARE = "logs/compare/{compareId}"
PATH_POST_COMPARE_STATUS = "logs/compare/status"

PATH_POST_INCIDENTS = "logs/incidents"
PATH_GET_INCIDENT_ID = "logs/incidents/{incidentId}"
PATH_DELETE_INCIDENT = "logs/incidents/{incidentId}"
PATH_POST_INCIDENT_STATUS = "logs/incidents/status"
